.. image:: https://readthedocs.org/projects/ashendb/badge/?version=latest
    :target: https://ashendb.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
      
AshenDB
=======

**AshenDB** is a another stupid library for using json as Database. It mimics MongoDB functionalities.
